<?php
/**
 * @file
 * Theme functions.
 */
 
/**
 * Override HTML for links.
 */
function mojo_links($variables) {
  // Display the main menu as a drop-down menu.
  if (theme_get_setting('use_dropdowns') && array_key_exists('class', $variables['attributes']) && array_key_exists('1', $variables['attributes']['class']) && $variables['attributes']['class']['1'] == 'main-menu') {
    $pid = variable_get('menu_main_links_source', 'main-menu');
    $tree = menu_tree($pid);
    return drupal_render($tree);
  }
  return theme_links($variables);
}
 
 /**
 * Override HTML for menu trees.
 */
function mojo_menu_tree($variables) {
  return '<ul class="menu tree">' . $variables['tree'] . '</ul>';
}

/**
 * Override HTML for primary and secondary local tasks.
 */
function mojo_menu_local_tasks(&$vars) {
  $output = '';

  if (!empty($vars['primary'])) {
    $vars['primary']['#prefix'] = '<h2 class="element-invisible">' . t('Primary tasks') . '</h2>';
    $vars['primary']['#prefix'] .= '<ul class="menu navbar taskbar">';
    $vars['primary']['#suffix'] = '</ul>';
    $output .= drupal_render($vars['primary']);
  }
  if (!empty($variables['secondary'])) {
    $vars['secondary']['#prefix'] = '<h2 class="element-invisible">' . t('Secondary tasks') . '</h2>';
    $vars['secondary']['#prefix'] .= '<ul class="menu navbar pipeline">';
    $vars['secondary']['#suffix'] = '</ul>';
    $output .= drupal_render($vars['secondary']);
  }

  return $output;
}

/**
 * Override HTML for breadcrumb trail.
 */
function mojo_breadcrumb($vars) {
  $breadcrumb = $vars['breadcrumb'];
  $breadcrumb_display = theme_get_setting('mojo_breadcrumb_display');

  // Check theme setting to display breadcrumbs.
  if ($breadcrumb_display == 'yes' || $breadcrumb_display == 'admin' && arg(0) == 'admin') {
    
    // Remove the Home link.
    if (!theme_get_setting('mojo_breadcrumb_home')) {
      array_shift($breadcrumb);
    }
  
    if (!empty($breadcrumb)) {
      $breadcrumb_separator = filter_xss(theme_get_setting('mojo_breadcrumb_separator'));
      
      $output = '<h2 class="element-invisible">' . t('You are here') . '</h2>';
      $output .= '<p class="breadcrumb">' . implode($breadcrumb_separator, $breadcrumb);
      
      // Add page title to breadcrumbs.
      if (theme_get_setting('mojo_breadcrumb_title')) {
        $output .= ' ' . $breadcrumb_separator . ' ' . drupal_get_title();
      }
      
      // Add a trailing separator.
      if (theme_get_setting('mojo_breadcrumb_trailing')) {
        $output .= ' ' . $breadcrumb_separator;
      }
      
      $output .= '</p>';
      return $output;
    }
  }
  return '';
}
